
# PAL: A Physically-Based Animation Library

This library should be considered a toolbox for the development of physically-based animation research.
It is designed to be modular, easy to use, and easy to extend.
In particular, it is designed to be emphasize fast creative and experimental prototyping.


## Installation

We're working on a pip installation, but in the meantime, you can clone the repository and install the package locally.
```
git clone https://github.com/otmanon/pal.git
```

Installation is recommended on a fresh conda directory:

```
conda create -n pal
conda activate pal
```

Finally, install the dependencies:
```
pip install -r requirements.txt
```



